@@ -9,7 +9,7 @@ class Main:
         pass
 
     def FormatUsage(self, parser, action):
-        format_string = "e2e_cli" + " " + action + " [-h]" + " {add,delete,list} ... " + "alias"
+        format_string = "e2e_cli" + " " + action + " [-h]" + " {create,delete,list,edit/update} ... " + "alias"
         parser.usage = format_string
 
     def FormatUsageCommand(self, parser, action, command):
@@ -35,46 +35,46 @@ class Main:
 
     def node(self, parser):
         node_sub_parser = parser.add_subparsers(title="node Commands", dest="node_commands")
-        node_add_sub_parser = node_sub_parser.add_parser("add", help="To create a new node")
+        node_create_sub_parser = node_sub_parser.add_parser("create", help="To create a new node")
         node_delete_sub_parser = node_sub_parser.add_parser("delete", help="To delete a specific node")
         node_list_sub_parser = node_sub_parser.add_parser("list", help="To get a list of all nodes")
         node_get_sub_parser = node_sub_parser.add_parser("get", help="To get a list of all nodes")
         parser.add_argument("alias", type=str, help="The name of your API access credentials")
-        self.FormatUsageCommand(node_add_sub_parser, "node", "add")
+        self.FormatUsageCommand(node_create_sub_parser, "node", "create")
         self.FormatUsageCommand(node_delete_sub_parser, "node", "delete")
         self.FormatUsageCommand(node_list_sub_parser, "node", "list")
         self.FormatUsageCommand(node_get_sub_parser, "node", "get")
 
     def lb(self, parser):
         node_sub_parser = parser.add_subparsers(title="LB Commands", dest="lb_commands")
-        node_add_sub_parser = node_sub_parser.add_parser("add", help="To create a new node")
+        node_create_sub_parser = node_sub_parser.add_parser("create", help="To create a new node")
         node_delete_sub_parser = node_sub_parser.add_parser("delete", help="To delete a specific node")
         node_list_sub_parser = node_sub_parser.add_parser("list", help="To get a list of all nodes")
         node_edit_sub_parser = node_sub_parser.add_parser("edit", help="To get a list of all nodes")
         parser.add_argument("alias", type=str, help="The name of your API access credentials")
-        self.FormatUsageCommand(node_add_sub_parser, "node", "add")
+        self.FormatUsageCommand(node_create_sub_parser, "node", "create")
         self.FormatUsageCommand(node_delete_sub_parser, "node", "delete")
         self.FormatUsageCommand(node_list_sub_parser, "node", "list")
         self.FormatUsageCommand(node_edit_sub_parser, "node", "edit")
 
     def bucket(self, parser):
         bucket_sub_parser = parser.add_subparsers(title="bucket Commands", dest="bucket_commands")
-        bucket_add_sub_parser = bucket_sub_parser.add_parser("add", help="To create a new bucket")
+        bucket_create_sub_parser = bucket_sub_parser.add_parser("create", help="To create a new bucket")
         bucket_delete_sub_parser = bucket_sub_parser.add_parser("delete", help="To delete a specific bucket")
         bucket_delete_sub_parser = bucket_sub_parser.add_parser("list", help="To get a list of all buckets")
         parser.add_argument("alias", type=str, help="The name of your API access credentials")
-        self.FormatUsageCommand(bucket_add_sub_parser, "bucket", "add")
+        self.FormatUsageCommand(bucket_create_sub_parser, "bucket", "create")
         self.FormatUsageCommand(bucket_delete_sub_parser, "bucket", "delete")
         self.FormatUsageCommand(bucket_delete_sub_parser, "bucket", "list")    
 
 
     def dbaas(self, parser):
         dbaas_sub_parser = parser.add_subparsers(title="DBaaS Commands", dest="dbaas_commands")
-        dbaas_add_sub_parser = dbaas_sub_parser.add_parser("add", help="To launch a new dbaas")
+        dbaas_create_sub_parser = dbaas_sub_parser.add_parser("create", help="To launch a new dbaas")
         dbaas_delete_sub_parser = dbaas_sub_parser.add_parser("delete", help="To delete a created dbaas")
         dbaas_list_sub_parser = dbaas_sub_parser.add_parser("list", help="To list all of your dbaas")
         parser.add_argument("alias", type=str, help="The name of your API access credentials")
-        self.FormatUsageCommand(dbaas_add_sub_parser, "dbaas", "add")
+        self.FormatUsageCommand(dbaas_create_sub_parser, "dbaas", "create")
         self.FormatUsageCommand(dbaas_list_sub_parser, "dbaas", "list")
         self.FormatUsageCommand(dbaas_delete_sub_parser, "dbaas", "delete")
 
