@@ -12,13 +12,17 @@ class NodeRouting:
         if self.arguments.node_commands is None:
             subprocess.call(['e2e_cli', 'node', '-h'])
 
-        elif self.arguments.node_commands == 'add':
+        elif self.arguments.node_commands == 'create':
             Node_operations = NodeCrud(alias=self.arguments.alias )
             if(Node_operations.possible):
                         try:
-                           Node_operations.add_node()
+                           Node_operations.create_node()
                         except KeyboardInterrupt:
-                            Py_version_manager.py_print(" ")   
+                            Py_version_manager.py_print(" ")  
+                        except Exception as e:
+                            e=str(e)
+                            if(e=="'data'" or e=="'code'"):
+                                Py_version_manager.py_print("Oops!! Your access credentials seems to have expired")       
 
         elif self.arguments.node_commands == 'delete':
             Node_operations = NodeCrud(alias=self.arguments.alias)
@@ -27,14 +31,22 @@ class NodeRouting:
                            Node_operations.delete_node()
                         except KeyboardInterrupt:
                             Py_version_manager.py_print(" ")
+                        except Exception as e:
+                            e=str(e)
+                            if(e=="'data'" or e=="'code'"):
+                                Py_version_manager.py_print("Oops!! Your access credentials seems to have expired")
 
         elif self.arguments.node_commands == 'get':
             Node_operations = NodeCrud(alias=self.arguments.alias)
             if(Node_operations.possible):
                         try:
                            Node_operations.get_node_by_id()
-                        except:
-                            Py_version_manager.py_print(" ")   
+                        except KeyboardInterrupt:
+                            Py_version_manager.py_print(" ")
+                        except Exception as e:
+                            e=str(e)
+                            if(e=="'data'" or e=="'code'"):
+                                Py_version_manager.py_print("Oops!! Your access credentials seems to have expired")
         
         elif self.arguments.node_commands == 'list':
             Node_operations = NodeCrud(alias=self.arguments.alias)
@@ -42,6 +54,9 @@ class NodeRouting:
                         try: 
                            Node_operations.list_node()
                         except KeyboardInterrupt:
-                            Py_version_manager.py_print(" ")   
-
+                            Py_version_manager.py_print(" ")
+                        except Exception as e:
+                            e=str(e)
+                            if(e=="'data'" or e=="'code'"):
+                                Py_version_manager.py_print("Oops!! Your access credentials seems to have expired")
 
